==> bigloo1.3b.tar.gz: bigloo1.3/comptime1.3/Cc/ld.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1993 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/comptime1.2/Cc/ld.scm ...            */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Jul 17 09:37:55 1992                          */
;*    Last change :  Mon Apr  5 15:27:58 1993  (serrano)               */
;*                                                                     */
;*    Ok, il ne reste plus qu'a linker. On s`en occupe.                */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module cc_ld
   (include "Tools/trace.sch")
   (export  (ld name))
   (import  tools_speek
	    engine_param))

;*---------------------------------------------------------------------*/
;*    ld ...                                                           */
;*    -------------------------------------------------------------    */
;*    Le link se fait avec plusieurs fichiers:                         */
;*       1- Le fichier .o resultat de la compilation courrante         */
;*       2- Tous les .o qui ont ete passes en argument                 */
;*       3- Tous les .o qui correspondent aux fichiers de presents     */
;*          dans les clauses `with' du main.                           */
;*---------------------------------------------------------------------*/
(define (ld name)
   (verbose "   . ld (" *cc* ")" #\Newline)
   (let ((dest (if (string? *dest*)
		   *dest*
		   "a.out")))
      (let ((ld-args (string-append name ".o"           ;; le nom du .o main
				    " " *with-files*    ;; les modules with
				    *o-files*           ;; les .o du user
				    " -o " dest         ;; le nom de l'exec
				    " "  *cc-options*   ;; les options de cc
				    " -L" *lib-dir*     ;; les paths
				    (if *c-debug*       ;; le debug
					(string-append " " *c-debug-option*)
					"")
				    (if *strip*         ;; strip l'executable ?
					" -s"
					"")
				    " " *ld-options*    ;; les options de ld
				    " -l" *bigloo-lib*  ;; la librairie bigloo
				    " -lm")))           ;; la librairie math
	 (trace other "Je vais executer la commande: " #\Newline
		(string-append *cc* " " ld-args))
	 (let ((res (system (string-append *cc* " " ld-args))))
	    (if  (not (=fx res 0))
		 (error "ld" "cc problem" res))))))

==> bigloo_1.8b.orig.tar.gz: bigloo-1.8b.orig/comptime1.8/Cc/ld.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/comptime1.8/Cc/ld.scm                */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Jul 17 09:37:55 1992                          */
;*    Last change :  Tue Feb  6 13:31:20 1996 (serrano)                */
;*                                                                     */
;*    Ok, il ne reste plus qu'a linker. On s`en occupe.                */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module cc_ld
   (include "Tools/trace.sch")
   (export  (ld name boolean))
   (import  tools_speek
	    tools_error
	    cc_exec
	    engine_param))

;*---------------------------------------------------------------------*/
;*    list-of-string->string ...                                       */
;*---------------------------------------------------------------------*/
(define (list-of-string->string l)
   (let loop ((l (reverse l))
	      (r ""))
      (if (null? l)
	  r
	  (loop (cdr l)
		(string-append (car l) " " r)))))

;*---------------------------------------------------------------------*/
;*    ld ...                                                           */
;*---------------------------------------------------------------------*/
(define (ld name need-to-return)
   (cond
      ((string=? *os* "unix")
       (unix-ld name need-to-return))
      (else
       (user-error "ld" "Unknow os" *os*))))

;*---------------------------------------------------------------------*/
;*    ld ...                                                           */
;*    -------------------------------------------------------------    */
;*    Le link se fait avec plusieurs fichiers:                         */
;*       1- Le fichier .o resultat de la compilation courrante         */
;*       2- Tous les .o qui ont ete passes en argument                 */
;*       3- Tous les .o qui correspondent aux fichiers de presents     */
;*          dans les clauses `with' du main.                           */
;*---------------------------------------------------------------------*/
(define (unix-ld name need-to-return)
   (verbose 1 "   . ld (" *cc* ")" #\Newline)
   (let ((dest (if (string? *dest*)
		   *dest*
		   "a.out")))
      (let* ((libs      (let loop ((lib (append *bigloo-lib*
						*bigloo-user-lib*))
				   (res ""))
			   (if (null? lib)
			       res
			       (loop (cdr lib)
				     (string-append (car lib) " " res)))))
	     (ld-args   (string-append name ".o";; le nom du .o main
				       " "
				       (list-of-string->string *with-files*)
				       (list-of-string->string *o-files*)
				       " -o " dest;; le nom de l'exec
				       " "  *cc-options*;; les options de cc
				       " -L" *lib-dir*;; les paths
				       (if *c-debug*;; le debug
					   (string-append " " *c-debug-option*)
					   "")
				       (if *strip*;; strip l'executable ?
					   " -s"
					   "")
				       " " *ld-options*;; les options de ld
				       libs))
	     (cmd/ld    (string-append *cc* " " ld-args))
	     (rm/myself (if need-to-return
				""
				(string-append "\rm -f " (exec-fname) ";")))
	     (cmd       (string-append "if " cmd/ld #" 2>&1 >/dev/null \n"
				       #"then\n"
				       rm/myself
				       "exit $?"
				       #"\nelse\n"
				       rm/myself
				       "exit 1"
				       #"\nfi")))
	 (verbose 2 "        "  cmd/ld #\Newline)
	 (exec cmd need-to-return "ld"))))
